"""
Simple Python terminal (TUI) multi-line editor
"""

from .tui_editor import TuiEditor
